@@ -5,7 +5,10 @@ from io import BytesIO
 from warnings import warn
 from re import sub
 from base64 import b64encode,b64decode
-
+try:
+    import requests as request_image
+except ImportError:
+    request_image = None
 try:
     from PIL import Image as pilimage
     from numpy import asarray as toarray
@@ -13,9 +16,7 @@ try:
     from numpy import squeeze
     from numpy import max as npmax
     from numpy import min as npmin
-    import requests as request_image
 except ImportError:
-    request_image = None
     raise ImportError('Could not import PIL.Image. or Numpy '
         'This library requires PIL >= 7.0.0 and numpy >= 1.18.1')
 
@@ -37,7 +38,7 @@ def imread(image_path,resize=None,color_mode = None,interpolation='nearest',dtyp
         image_path: Image Path.
         resize: (width,height) tuple
         color_mode: default is None
-            you can also use color_mode as`rgba` or `grayscale`
+            you can also use color_mode as `rgb` or `rgba` or `grayscale`
         interpolation:
             Interpolation method used to resample the image if the
             target size is different from that of the loaded image.
